==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/ru.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Панель управления",
    "Dashboard app" : "Приложения Панели управления",
    "Show something" : "Показать",
    "Customize" : "Настроить",
    "Edit widgets" : "Редактировать виджеты",
    "Get more widgets from the app store" : "Получите больше виджетов в магазине приложений",
    "Change background image" : "Изменить фоновое изображение",
    "Weather service" : "Погода",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "В целях вашей конфиденциальности данные о погоде запрашиваются вашим сервером Nextcloud от вашего имени, поэтому служба погоды не получает никакой личной информации.",
    "Weather data from Met.no" : "Погода от Met.no",
    "geocoding with Nominatim" : "геокодирование с Nominatim",
    "elevation data from OpenTopoData" : "данные о высоте из OpenTopoData",
    "Weather" : "Прогноз погоды",
    "Status" : "Состояние",
    "Good evening, {name}" : "Добрый вечер, {name}",
    "Good evening" : "Добрый вечер",
    "Good afternoon, {name}" : "Добрый день, {name}",
    "Good afternoon" : "Добрый день",
    "Good morning, {name}" : "Доброе утро, {name}",
    "Good morning" : "Доброе утро",
    "Good night, {name}" : "Доброй ночи, {name}",
    "Good night" : "Доброй ночи",
    "Pick from files" : "Выбрать из файлов",
    "Default images" : "Изображения по умолчанию",
    "Plain background" : "Обычный фон",
    "Insert from {productName}" : "Вставить из {productName}"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-22.2.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/ru.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Виджеты",
    "Dashboard app" : "Приложение Виджеты",
    "Show something" : "Показать",
    "Customize" : "Настроить",
    "Edit widgets" : "Редактировать виджеты",
    "Get more widgets from the App Store" : "Загрузить виджеты из магазина приложений",
    "Change background image" : "Изменить фоновое изображение",
    "Weather service" : "Погода",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "В целях вашей конфиденциальности данные о погоде запрашиваются вашим сервером Nextcloud от вашего имени, поэтому служба погоды не получает никакой личной информации.",
    "Weather data from Met.no" : "Погода от Met.no",
    "geocoding with Nominatim" : "геокодирование с Nominatim",
    "elevation data from OpenTopoData" : "данные о высоте из OpenTopoData",
    "Weather" : "Прогноз погоды",
    "Status" : "Состояние",
    "Good morning" : "Доброе утро",
    "Good morning, {name}" : "Доброе утро, {name}",
    "Good afternoon" : "Добрый день",
    "Good afternoon, {name}" : "Добрый день, {name}",
    "Good evening" : "Добрый вечер",
    "Good evening, {name}" : "Добрый вечер, {name}",
    "Hello" : "Здравствуйте",
    "Hello, {name}" : "Здравствуйте, {name}!",
    "Pick from Files" : "Выбрать из файлов",
    "Default images" : "Изображения по умолчанию",
    "Plain background" : "Обычный фон",
    "Insert from {productName}" : "Вставить из {productName}",
    "Get more widgets from the app store" : "Загрузить виджеты из магазина приложений",
    "Good night, {name}" : "Доброй ночи, {name}",
    "Good night" : "Доброй ночи",
    "Pick from files" : "Выбрать из файлов"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
